==> mediawiki-core-1.28.0-rc.1.tar.gz: mediawiki-1.28.0-rc.1/includes/libs/rdbms/lbfactory/LBFactorySingle.php <==
<?php
/**
 * Simple generator of database connections that always returns the same object.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 * http://www.gnu.org/copyleft/gpl.html
 *
 * @file
 * @ingroup Database
 */

/**
 * An LBFactory class that always returns a single database object.
 */
class LBFactorySingle extends LBFactory {
	/** @var LoadBalancerSingle */
	private $lb;

	/**
	 * @param array $conf An associative array with one member:
	 *  - connection: The IDatabase connection object
	 */
	public function __construct( array $conf ) {
		parent::__construct( $conf );

		if ( !isset( $conf['connection'] ) ) {
			throw new InvalidArgumentException( "Missing 'connection' argument." );
		}

		$lb = new LoadBalancerSingle( array_merge( $this->baseLoadBalancerParams(), $conf ) );
		$this->initLoadBalancer( $lb );
		$this->lb = $lb;
	}

	/**
	 * @param IDatabase $db Live connection handle
	 * @param array $params Parameter map to LBFactorySingle::__constructs()
	 * @return LBFactorySingle
	 * @since 1.28
	 */
	public static function newFromConnection( IDatabase $db, array $params = [] ) {
		return new static( [ 'connection' => $db ] + $params );
	}

	/**
	 * @param bool|string $domain (unused)
	 * @return LoadBalancerSingle
	 */
	public function newMainLB( $domain = false ) {
		return $this->lb;
	}

	/**
	 * @param bool|string $domain (unused)
	 * @return LoadBalancerSingle
	 */
	public function getMainLB( $domain = false ) {
		return $this->lb;
	}

	/**
	 * @param string $cluster External storage cluster name (unused)
	 * @return LoadBalancerSingle
	 */
	public function newExternalLB( $cluster ) {
		return $this->lb;
	}

	/**
	 * @param string $cluster External storage cluster name (unused)
	 * @return LoadBalancerSingle
	 */
	public function getExternalLB( $cluster ) {
		return $this->lb;
	}

	/**
	 * @param string|callable $callback
	 * @param array $params
	 */
	public function forEachLB( $callback, array $params = [] ) {
		call_user_func_array( $callback, array_merge( [ $this->lb ], $params ) );
	}
}

==> mediawiki-core-1.34.1.tar.gz: mediawiki-1.34.1/includes/libs/rdbms/lbfactory/LBFactorySingle.php <==
<?php
/**
 * Simple generator of database connections that always returns the same object.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 * http://www.gnu.org/copyleft/gpl.html
 *
 * @file
 * @ingroup Database
 */

namespace Wikimedia\Rdbms;

use InvalidArgumentException;
use BadMethodCallException;

/**
 * An LBFactory class that always returns a single database object.
 */
class LBFactorySingle extends LBFactory {
	/** @var LoadBalancerSingle */
	private $lb;

	/**
	 * @param array $conf An associative array with one member:
	 *  - connection: The IDatabase connection object
	 */
	public function __construct( array $conf ) {
		parent::__construct( $conf );

		if ( !isset( $conf['connection'] ) ) {
			throw new InvalidArgumentException( "Missing 'connection' argument." );
		}

		$lb = new LoadBalancerSingle( array_merge(
			$this->baseLoadBalancerParams( $this->getOwnershipId() ),
			$conf
		) );
		$this->initLoadBalancer( $lb );

		$this->lb = $lb;
	}

	/**
	 * @param IDatabase $db Live connection handle
	 * @param array $params Parameter map to LBFactorySingle::__constructs()
	 * @return LBFactorySingle
	 * @since 1.28
	 */
	public static function newFromConnection( IDatabase $db, array $params = [] ) {
		return new static( array_merge(
			[ 'localDomain' => $db->getDomainID() ],
			$params,
			[ 'connection' => $db ]
		) );
	}

	public function newMainLB( $domain = false, $owner = null ) {
		throw new BadMethodCallException( "Method is not supported." );
	}

	public function getMainLB( $domain = false ) {
		return $this->lb;
	}

	public function newExternalLB( $cluster, $owner = null ) {
		throw new BadMethodCallException( "Method is not supported." );
	}

	public function getExternalLB( $cluster ) {
		throw new BadMethodCallException( "Method is not supported." );
	}

	public function getAllMainLBs() {
		return [ 'DEFAULT' => $this->lb ];
	}

	public function getAllExternalLBs() {
		return [];
	}

	public function forEachLB( $callback, array $params = [] ) {
		if ( isset( $this->lb ) ) { // may not be set during _destruct()
			$callback( $this->lb, ...$params );
		}
	}
}
